package com.aitrainer.api.security

import com.aitrainer.api.service.ServiceBeans
import com.aitrainer.api.service.UserDetailsServiceImpl
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration
import org.springframework.security.authentication.AuthenticationManager
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder
import org.springframework.security.config.annotation.web.builders.HttpSecurity
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity
import org.springframework.security.config.http.SessionCreationPolicy
import org.springframework.security.web.SecurityFilterChain
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter
import org.springframework.web.servlet.config.annotation.CorsRegistry
import org.springframework.web.servlet.config.annotation.EnableWebMvc
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer

@Configuration
@EnableWebSecurity
@EnableWebMvc
class JwtSecurityConfig {
    @Autowired
    private val jwtAuthenticationEntryPoint: JwtAuthenticationEntryPoint? = null

    @Autowired
    private val jwtUserDetailsService: UserDetailsServiceImpl? = null

    @Autowired
    private val serviceBeans: ServiceBeans? = null

    @Autowired
    private var jwtRequestFilter: JwtRequestFilter? = null

    private fun authManager(http: HttpSecurity): AuthenticationManager {
        val authenticationManagerBuilder = http.getSharedObject(
            AuthenticationManagerBuilder::class.java
        )
        authenticationManagerBuilder.userDetailsService(jwtUserDetailsService)
            .passwordEncoder(serviceBeans!!.passwordEncoder())
        return authenticationManagerBuilder.build()
    }

    @Bean
    @Throws(Exception::class)
    fun filterChain(httpSecurity: HttpSecurity): SecurityFilterChain {

        httpSecurity.cors().and().csrf().disable().authorizeHttpRequests().requestMatchers("/api/authenticate").permitAll()
            .anyRequest().authenticated().and().exceptionHandling()
            .authenticationEntryPoint(jwtAuthenticationEntryPoint).and()
            .addFilterAfter(jwtRequestFilter, UsernamePasswordAuthenticationFilter::class.java).

            // make sure we use stateless session; session won't be used to
            // store user's state.
        sessionManagement().sessionCreationPolicy(SessionCreationPolicy.STATELESS)
        return httpSecurity.build();
    }

    @Bean
    fun corsMappingConfigurer(): WebMvcConfigurer? {
        return object : WebMvcConfigurer {
            override fun addCorsMappings(registry: CorsRegistry) {
                registry.addMapping("/**")
                    .allowedOriginPatterns("https://diet4you.hu", "https://diet4you.eu", "https://*.diet4you.eu", "https://*.diet4you.hu", "https://*.workouttest.org", "http://localhost:[*]")
                    //.allowedOrigins("*")
                    .allowedMethods("POST", "GET", "OPTIONS", "HEAD")
                    .maxAge(3600)
                    .allowedHeaders("*")
            }
        }
    }
}