package com.aitrainer.api.test

import com.aitrainer.api.controller.PurchaseController
import com.aitrainer.api.model.Purchase
import com.aitrainer.api.repository.PurchaseRepository
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import kotlin.test.assertEquals
import kotlin.test.assertTrue

@SpringBootTest
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class PurchaseTest {

    @Autowired
    private lateinit var purchaseRepository: PurchaseRepository


    @Test
    fun testGetPurchaseByCustomerId() {
        val controller = PurchaseController(purchaseRepository)
        val response = controller.getAllByCustomerId(62)

        val purchases = response.body

        assertTrue(purchases is List)
        assertTrue(purchases.isNotEmpty())
        assertEquals(purchases.size, 2)
        assertEquals(purchases[0].productId, 1)

    }

    @Test
    fun testPurchaseInsert() {
        val purchase = Purchase(
           productId = 2,
           dateAdd = "2020-11-05 12:00:00",
           customerId = 1,
           purchaseSum = 2000.0,
           currency = "HUF"
        )

        val controller = PurchaseController(purchaseRepository)
        val response = controller.insertPurchase(purchase)

        val purchaseNew = response.body

        assertEquals(purchaseNew!!.productId, 2)
        assertEquals(purchaseNew.customerId, 1)

        purchaseRepository.delete(purchaseNew)

    }

}