package com.aitrainer.api.test.diet

import com.aitrainer.api.model.diet.Store
import com.aitrainer.api.test.Tokenizer
import com.google.gson.Gson
import org.junit.jupiter.api.BeforeAll
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.junit.jupiter.api.extension.ExtendWith
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.MediaType
import org.springframework.test.context.junit.jupiter.SpringExtension
import org.springframework.test.web.servlet.MockMvc
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get
import org.springframework.test.web.servlet.result.MockMvcResultMatchers.*


@ExtendWith(SpringExtension::class)
@SpringBootTest
@AutoConfigureMockMvc
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class StoreTest {

    @Autowired
    private lateinit var mockMvc: MockMvc

    private val store = Store(
        storeId = 1,
        storeName = "Tesco",
        country = "HU"
    )
    private val store2 = Store(
        storeId = 2,
        storeName = "Auchan",
        country = "HU"
    )
    private val store3 = Store(
        storeId = 3,
        storeName = "Aldi",
        country = "HU"
    )
    private val store4 = Store(
        storeId = 4,
        storeName = "Aldi",
        country = "DE"
    )

    private var authToken: String? = ""

    @BeforeAll
    fun initTest() {
        authToken = Tokenizer.getToken()
    }


    @Test
    fun `insert recipes successfully`() {

        mockMvc.perform(
            MockMvcRequestBuilders.post("/api/store")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(toJson(store))
        )
        .andExpect(status().isOk)
        .andExpect(jsonPath("$.storeName").value("Tesco"))
        .andExpect(jsonPath("$.country").value("HU"))

        mockMvc.perform(
            MockMvcRequestBuilders.post("/api/store")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(toJson(store2))
        )
            .andExpect(status().isOk)
        mockMvc.perform(
            MockMvcRequestBuilders.post("/api/store")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(toJson(store3))
        )
            .andExpect(status().isOk)
        mockMvc.perform(
            MockMvcRequestBuilders.post("/api/store")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(toJson(store4))
        )
            .andExpect(status().isOk)
    }

    @Test
    fun `get all stores successfully`() {

        // Act & Assert
        mockMvc.perform(get("/api/store" )
            .header("Authorization", "Bearer $authToken")
            .contentType(MediaType.APPLICATION_JSON))
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.[0].storeName").value("Tesco"))
            .andExpect(jsonPath("$.[1].storeName").value("Auchan"))
            .andExpect(jsonPath("$.[2].storeName").value("Aldi"))
            .andExpect(jsonPath("$.[3].storeName").value("Aldi"))
            .andExpect(jsonPath("$.[3].country").value("DE"))

    }

    @Test
    fun `get store by name successfully`() {

        // Act & Assert
        mockMvc.perform(get("/api/store/Aldi/HU")
            .header("Authorization", "Bearer $authToken")
            .contentType(MediaType.APPLICATION_JSON))
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.storeName").value("Aldi"))
            .andExpect(jsonPath("$.country").value("HU"))

    }

    @Test
    fun `get recipe by name unsuccessfully`() {

        // Act & Assert
        mockMvc.perform(get("/api/store/Aldi/AT")
            .header("Authorization", "Bearer $authToken")
            .contentType(MediaType.APPLICATION_JSON))
            .andExpect(status().isNotFound)

    }

    private fun toJson(obj: Any): String {
        return Gson().toJson(obj)
    }
}
